@@ -1,3 +1,4 @@
+
 import pandas as pd
 from IPython.display import Math, display, Markdown
 from sympy import latex
@@ -94,8 +95,12 @@ class Equations:
 
             # except:
             #     print(f"{ref}{variable:<{a}}   {'':<{b}} | {solution:>{c}.3g}")
+        # if getmarkdown == True:
+        #
+        # else:
         display(Markdown(mymarkdown))
         # print(mymarkdown)
+        #
         print("\n" * 3)
 
     def markans(self, *highs):
@@ -274,18 +279,6 @@ class color:
     END = "\033[0m"
 
 
-class Bracers:
-    def __init__(self):
-
-        self.myeqns = Equations()
-
-    def add_loads(self, load):
-        self.loads = self.loads + load
-
-    def combine_loads(self):
-        myloads = [self.windward, self.leeward, self.seismic]
-
-
 class Load:
     def __init__(self, Dead=0, Live=0, Live_roof=0, Snow=0, Rain=0, Wind=0):
         # self.D = Dead * u.kips / (u.inch ** 2)
@@ -297,6 +290,38 @@ class Load:
         self.W = Wind * u.kips
         self.myeqns = Equations()
 
+        D = self.D
+        L = self.L
+        L_r = self.L_r
+        S = self.S
+        R = self.R
+        W = self.W
+
+        omega = 1.67
+        phi = 0.9
+        mymax = 0
+
+        for i in range(1, 6):
+            combo_value_LRFD = self.combo_loads("LRFD", i)
+            # print(f"Combonation {i} = {(combo_value_LRFD):.3}")
+            if combo_value_LRFD > mymax:
+                mymax = combo_value_LRFD
+                mymax_combo = i
+        self.LRFD_max = mymax
+
+        self.myeqns.maxes.append(f"LRFD Combo {mymax_combo}")
+
+        mymax = 0
+
+        for i in range(1, 8):
+            combo_value_ASD = self.combo_loads("ASD", i)
+
+            if combo_value_ASD > mymax:
+                mymax = combo_value_ASD
+                mymax_combo = i
+        self.ASD_max = mymax
+        self.myeqns.maxes.append(f"ASD Combo {mymax_combo}")
+
     def combo_loads(self, load_type, combo):
         D = self.D
         L = self.L
@@ -457,40 +482,6 @@ class Load:
                 )
                 return 0.6 * D + 0.6 * W
 
-    def get_max_loads(self):
-
-        D = self.D
-        L = self.L
-        L_r = self.L_r
-        S = self.S
-        R = self.R
-        W = self.W
-
-        omega = 1.67
-        phi = 0.9
-        mymax = 0
-
-        for i in range(1, 6):
-            combo_value_LRFD = self.combo_loads("LRFD", i)
-            # print(f"Combonation {i} = {(combo_value_LRFD):.3}")
-            if combo_value_LRFD > mymax:
-                mymax = combo_value_LRFD
-                mymax_combo = i
-        self.LRFD_max = mymax
-
-        self.myeqns.maxes.append(f"LRFD Combo {mymax_combo}")
-
-        mymax = 0
-
-        for i in range(1, 8):
-            combo_value_ASD = self.combo_loads("ASD", i)
-
-            if combo_value_ASD > mymax:
-                mymax = combo_value_ASD
-                mymax_combo = i
-        self.ASD_max = mymax
-        self.myeqns.maxes.append(f"ASD Combo {mymax_combo}")
-
 
 def convert_to_float(frac_str):
     # This takes the inputed string like ("2", "5/8","2 5/8" and converts those to in)
@@ -515,6 +506,7 @@ class Member:
         self.F_u = 58 * u.kips / (u.inch ** 2)
         self.E = 29_000 * u.kips / (u.inch ** 2)
         self.myeqns = Equations()
+
         if designation != "none":
             try:
                 shapes = pd.read_excel(
@@ -534,13 +526,27 @@ class Member:
             myedition = shapes["Edition"] == "14th"
             mydesignation = shapes["Designation"] == designation
             myshape = shapes.loc[myedition & mydesignation]
+
             # This adds all of the attributes from the table as attributes of member
-            for column in myshape.columns:
-                try:
-                    exec(f"self.{column} = float(myshape[column])")
-                #                 print(f"'{column}' = {float(myshape[column])}")
-                except:
-                    pass
+
+            # Check if not PL
+            if designation.find("PL") > -1:
+                self.Type = "PL"
+                # print("PL!")
+
+            else:
+                for column in myshape.columns:
+                    shape_attribute = str(myshape[column]).split()[1]
+
+                    try:
+                        exec(f"self.{column} = float(shape_attribute)")
+
+                    except:
+                        if shape_attribute != "–":
+                            # print(shape_attribute)
+                            exec(f"self.{column} = shape_attribute")
+
+            # print(self.Type)
 
             # print(designation)
             # Space is necessary
@@ -548,26 +554,36 @@ class Member:
 
             mydimensions = designation.split("X")
 
-            if len(mydimensions) == 3:
-                self.w_plate = convert_to_float(mydimensions[1]) * u.inch
-                self.t_plate = convert_to_float(mydimensions[2]) * u.inch
+            if self.Type == "C":
+                self.t_member = self.tw * u.inch
+                # print("C is type")
+            elif self.Type == "W":
+                self.t_member = self.tf * u.inch
+                # print("C is type")
+
+            # Determine Width and thickness
+            elif len(mydimensions) == 3:
+                self.w_member = convert_to_float(mydimensions[1]) * u.inch
+                self.t_member = convert_to_float(mydimensions[2]) * u.inch
             else:
-                self.w_plate = convert_to_float(mydimensions[0]) * u.inch
-                self.t_plate = convert_to_float(mydimensions[1]) * u.inch
+                self.w_member = convert_to_float(mydimensions[0]) * u.inch
+                self.t_member = convert_to_float(mydimensions[1]) * u.inch
 
+            # print(self.w_member)
+
+            # Determine A_g
             try:
-
                 self.A_g = self.A_g * u.inch ** 2
             except:
-                self.A_g = self.w_plate * self.t_plate
+                self.A_g = self.w_member * self.t_member
 
                 self.myeqns.additem(
                     "A_g",
                     [
                         "A_g",
                         self.A_g,
-                        f"{self.w_plate} * {self.t_plate}",
-                        "w_plate * t_plate",
+                        f"{self.w_member} * {self.t_member}",
+                        "w_member * t_member",
                         "Gross area",
                     ],
                 )
@@ -581,7 +597,7 @@ class Member:
     def bolts(self, bolt_size, holes, load_transfer=1, *stagger):
         self.bolt_size = convert_to_float(bolt_size) * u.inch
         self.holes = holes
-        t = self.t_plate
+        t = self.t_member
         A_g = self.A_g
         # print(stagger)
         if self.bolt_size < 1 * u.inch:
@@ -592,7 +608,7 @@ class Member:
                     "hole_size",
                     self.hole_size,
                     f"{self.bolt_size} + 1 / 8 * u.inch",
-                    "bolt_size + 1 / 8 * u.inch",
+                    "$$size_{bolt} + 1 / 8 * u.inch$$",
                     "Table J3.3 and b4.36 (16.1-130,16.1-20)",
                 ],
             )
@@ -604,12 +620,12 @@ class Member:
                     "hole_size",
                     self.hole_size,
                     f"{self.bolt_size} + 3 / 16 * u.inch",
-                    "bolt_size + 3 / 16 * u.inch",
+                    "$$size_{bolt} + 3 / 16 * u.inch$$",
                     "Table J3.3 and b4.36 (16.1-130,16.1-20)",
                 ],
             )
 
-        self.A_hole = self.t_plate * self.hole_size
+        self.A_hole = self.t_member * self.hole_size
         self.A_holes = self.A_hole * self.holes
 
         self.myeqns.additem(
@@ -617,8 +633,8 @@ class Member:
             [
                 "Area of holes",
                 self.A_holes,
-                f"{self.t_plate} * {self.hole_size} * {self.holes}",
-                "t_plate * hole_size * holes",
+                f"{self.t_member} * {self.hole_size} * {self.holes}",
+                "$$t_{member} * size_{holes} * holes$$",
                 "",
             ],
         )
@@ -649,7 +665,7 @@ class Member:
                     "A_n from stagger",
                     A_n,
                     f"({A_g: .3} - {A_holes: .3}{stagger_equations}) * {load_transfer})",
-                    "(A_g - A_holes + stagger_equations) * load_transfer)",
+                    "$$(A_g - A_{holes} + stagger equations) * load transfer)$$",
                     "Stagger factor from Eq 3.2",
                 ],
             )
@@ -663,7 +679,7 @@ class Member:
                     "A_n",
                     A_n,
                     f"({A_g: .3} - {A_holes: .3} * {load_transfer})",
-                    "(A_g - A_holes * load transfer)",
+                    "$$(A_g - A_{holes} * load transfer)$$",
                     "Net area accounting for load transfer",
                 ],
             )
@@ -673,51 +689,101 @@ class Member:
         P_n_net = self.P_n_net
         # print(P_n_gross)
         # print(P_n_gross)
+        phi = 0.9
+
+        yield_strength_LRFD = P_n_gross * phi
         self.myeqns.additem(
             "LRFD Yield strength",
             [
                 "LRFD Yield strength",
-                0.9 * P_n_gross,
-                f"0.9 * {P_n_gross:.3g}",
-                "0.9 * {P_n_gross:.3g}",
+                yield_strength_LRFD,
+                f"{P_n_gross:.3g} * {phi}",
+                r"$$P_n * \phi$$",
                 "D2-1",
             ],
         )
+
+        phi = 0.75
+        rupture_strength_LRFD = 0.75 * P_n_net
         self.myeqns.additem(
             "LRFD Rupture strength",
             [
                 "LRFD Rupture strength",
                 0.75 * P_n_net,
-                f"0.75 * {P_n_net:.3g}",
-                "0.75 * {P_n_net:.3g}",
+                f"{P_n_net:.3g} * {phi}",
+                r"$$P_n * \phi$$",
                 "D2-2",
             ],
         )
 
+        if yield_strength_LRFD < rupture_strength_LRFD:
+            design_strength_LRFD = yield_strength_LRFD
+            try:
+                if design_strength_LRFD > self.LRFD_max:
+                    self.myeqns.greens.append("LRFD Yield strength")
+                else:
+                    self.myeqns.reds.append("LRFD Yield strength")
+            except:
+                self.myeqns.maxes.append("LRFD Yield strength")
+
+        else:
+            design_strength_LRFD = rupture_strength_LRFD
+            try:
+                if design_strength_LRFD > self.LRFD_max:
+                    self.myeqns.greens.append("LRFD Rupture strength")
+                else:
+                    self.myeqns.reds.append("LRFD Rupture strength")
+            except:
+                self.myeqns.maxes.append("LRFD Rupture strength")
+
+        omega = 1.67
+        yield_strength_ASD = P_n_gross / omega
         self.myeqns.additem(
             "ASD Yield strength",
             [
                 "ASD Yield strength",
-                P_n_gross / 1.67,
-                f"{P_n_gross:.3g} / 1.67",
-                "{P_n_gross:.3g} / 1.67",
+                P_n_gross / omega,
+                f"{P_n_gross:.3g} / {omega}",
+                r"$$\frac{P_n}{\omega}$$",
                 "D2-1",
             ],
         )
+        omega = 2
+        rupture_strength_ASD = P_n_net / 2
         self.myeqns.additem(
             "ASD Rupture strength",
             [
                 "ASD Rupture strength",
                 P_n_net / 2,
-                f"{P_n_net:.3g} / 2",
-                "P_n_net / 2",
+                f"{P_n_net:.3g} / {omega}",
+                r"$$\frac{P_n}{\omega}$$",
                 "D2-2",
             ],
         )
 
-    def reduction_factor(self, shape_type, x_bar=0, l_plate=0, w_plate=0, fasteners=0):
+        if yield_strength_ASD < rupture_strength_ASD:
+            design_strength_ASD = yield_strength_ASD
+            try:
+                if design_strength_ASD > self.ASD_max:
+                    self.myeqns.greens.append("ASD Yield strength")
+                else:
+                    self.myeqns.reds.append("ASD Yield strength")
+            except:
+                self.myeqns.maxes.append("ASD Yield strength")
+
+        else:
+            design_strength_ASD = rupture_strength_ASD
+            try:
+                if design_strength_ASD > self.ASD_max:
+                    self.myeqns.greens.append("ASD Rupture strength")
+                else:
+                    self.myeqns.reds.append("ASD Rupture strength")
+            except:
+                self.myeqns.maxes.append("ASD Rupture strength")
+
+    def reduction_factor(self, shape_type, x_bar=0, l_plate=0, w_member=0, fasteners=0):
         l = l_plate
-        w = w_plate
+        w = w_member
         x = x_bar
         if fasteners >= 4:
             self.myeqns.additem(
@@ -803,7 +869,7 @@ class Member:
         A_g = self.A_g
         A_n = self.A_n
         A_holes = self.A_holes
-        t = self.t_plate
+        t = self.t_member
 
         A_e = A_n * effective_factor
         self.myeqns.additem(
@@ -812,7 +878,7 @@ class Member:
                 "A_e",
                 A_e,
                 f"{A_n:.3g} * {effective_factor:.3g}",
-                "A_n * effective_factor",
+                "$$A_n * effective factor$$",
                 "D3-1",
             ],
         )
@@ -826,7 +892,7 @@ class Member:
                 "Nominal strength gross",
                 P_n_gross,
                 f"{F_y:.3} * {A_g:.3}",
-                "F_y * A_g",
+                "$$F_y * A_g$$",
                 "D2-1",
             ],
         )
@@ -840,15 +906,15 @@ class Member:
                 "Nominal strength net",
                 P_n_net,
                 f"{F_u:.3} * {A_e:.3}",
-                "F_u * A_e",
+                "$$F_u * A_e$$",
                 "D2-2",
             ],
         )
 
     def block_shear(self, x_bolts, y_bolts, rows=1, effective_factor=1):
         # l_plate = self.l_plate
-        # w_plate = self.w_plate
-        t_plate = self.t_plate
+        # w_member = self.w_member
+        t_member = self.t_member
         y_bolts = convert_to_float(y_bolts) * u.inch
         x_bolts = convert_to_float(x_bolts) * u.inch
 
@@ -859,19 +925,19 @@ class Member:
         A_hole = self.A_hole
         holes = self.holes
 
-        A_g = x_bolts * t_plate
+        A_g = x_bolts * t_member
         self.myeqns.additem(
             "Gross_area_in_shear",
             [
                 "Gross area in shear",
                 A_g,
-                f"{x_bolts} * {t_plate}",
-                "x_bolts * t_plate",
+                f"{x_bolts} * {t_member}",
+                "$$x_{bolts} * t_{member}$$",
                 "J4-5",
             ],
         )
-        A_nv = t_plate * ((x_bolts) - (holes - 0.5 * rows) * (d_hole))
-        A_nt = t_plate * ((y_bolts) - (0.5 * rows) * (d_hole))
+        A_nv = t_member * ((x_bolts) - (holes - 0.5 * rows) * (d_hole))
+        A_nt = t_member * ((y_bolts) - (0.5 * rows) * (d_hole))
         R_n = 0.6 * F_u * A_nv + effective_factor * F_u * A_nt
         R_n_u = 0.6 * F_y * A_g + effective_factor * F_u * A_nt
 
@@ -885,8 +951,8 @@ class Member:
             [
                 "Net area in shear",
                 A_nv,
-                f"{t_plate} * (({x_bolts}) - ({holes} - 0.5 * {rows}) * ({d_hole}))",
-                "t_plate * ((x_bolts) - (holes - 0.5 * rows) * (d_hole))",
+                f"{t_member} * (({x_bolts}) - ({holes} - 0.5 * {rows}) * ({d_hole}))",
+                "$$t_{member} * ((x_{bolts}) - (holes - 0.5 * rows) * (d_{hole}))$$",
                 "J4-5",
             ],
         )
@@ -895,8 +961,8 @@ class Member:
             [
                 "Net area in tension",
                 A_nt,
-                f"{t_plate} * (({y_bolts}) - (0.5 * {rows}) * ({d_hole}))",
-                "t_plate * ((y_bolts) - (0.5 * rows) * (d_hole))",
+                f"{t_member} * (({y_bolts}) - (0.5 * {rows}) * ({d_hole}))",
+                "$$t_{member} * ((y_{bolts}) - (0.5 * rows) * (d_{hole}))$$",
                 "J4-5",
             ],
         )
@@ -906,7 +972,7 @@ class Member:
                 "R_n",
                 R_n,
                 f"0.6 * {F_u} * {A_nv:.3g} + {effective_factor} * {F_u} * {A_nt:.3g}",
-                "0.6 * F_u * A_nv + effective_factor * F_u * A_nt",
+                "$$0.6 * F_u * A_{nv} + effective factor * F_u * A_{nt}$$",
                 "Eq 3.3",
             ],
         )
@@ -916,7 +982,7 @@ class Member:
                 "R_n_u",
                 R_n_u,
                 f"0.6 * {F_y} * {A_g:.3g} + {effective_factor} * {F_u} * {A_nt:.3g}",
-                "0.6 * F_y * A_g + effective_factor * F_u * A_nt",
+                "$$0.6 * F_y * A_g + effective factor * F_u * A_{nt}$$",
                 "Eq 3.4",
             ],
         )
@@ -992,8 +1058,6 @@ class Member:
             ],
         )
 
-        from math import pi
-
         F_e = (pi ** 2 * E) / self.slenderness ** 2
         self.myeqns.additem(
             "F_e",
@@ -1001,7 +1065,7 @@ class Member:
                 "F_e",
                 F_e,
                 f"(({pi:.3}^2 * {E})/ {self.slenderness}^2)",
-                r"$$(\frac{(\pi^2 * E)}{Slenderness^2})$$",
+                r"$$(\frac{(\pi^2 * E)}{(\frac{(L * K)}{r})^2})$$",
                 "E3-2,E3-3",
             ],
         )
@@ -1016,7 +1080,7 @@ class Member:
                 "P_cr",
                 P_cr,
                 f"(({pi:.3}^2 * {E} * {A_g})/ {self.slenderness}^2)",
-                r"$$(\frac{(\pi^2 * E * A)}{Slenderness^2})$$",
+                r"$$(\frac{(\pi^2 * E * A)}{(\frac{(L * K)}{r})^2})$$",
                 "E3-2,E3-3",
             ],
         )
@@ -1061,6 +1125,7 @@ class Member:
 
         phi = 0.9
         P_n_LRFD = P_n * phi
+        self.P_n_LRFD = P_n_LRFD
         self.myeqns.additem(
             "P_n_LRFD",
             [
@@ -1077,10 +1142,12 @@ class Member:
             else:
                 self.myeqns.reds.append("P_n_LRFD")
         except:
-            print("theres none")
+            pass
+            # print("theres none")
 
         omega = 1.67
         P_n_ASD = P_n / omega
+        self.P_n_ASD = P_n_ASD
         self.myeqns.additem(
             "P_n_ASD",
             [
@@ -1188,3 +1255,15 @@ class Frame:
 
         print(f"g_a = {g_a}")
         print(f"g_b = {g_b}")
+
+
+class Bracers:
+    def __init__(self):
+
+        self.myeqns = Equations()
+
+    def add_loads(self, load):
+        self.loads = self.loads + load
+
+    def combine_loads(self):
+        myloads = [self.windward, self.leeward, self.seismic]
\ No newline at end of file
